@@ -1,23 +1,8 @@
 /*
+ * Embedded Linux library
+ * Copyright (C) 2011-2014  Intel Corporation
  *
- *  Embedded Linux library
- *
- *  Copyright (C) 2011-2014  Intel Corporation. All rights reserved.
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +13,6 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/socket.h>
@@ -42,6 +26,7 @@
 #include "hashmap.h"
 #include "dbus.h"
 #include "private.h"
+#include "useful.h"
 #include "dbus-private.h"
 
 #define DEFAULT_SYSTEM_BUS_ADDRESS "unix:path=/var/run/dbus/system_bus_socket"
@@ -1496,7 +1481,7 @@ LIB_EXPORT bool l_dbus_register_object(struct l_dbus *dbus, const char *path,
 	va_list args;
 	const char *interface;
 	void *if_user_data;
-	bool r = true;;
+	bool r = true;
 
 	if (unlikely(!dbus))
 		return false;
@@ -1598,7 +1583,8 @@ LIB_EXPORT void *l_dbus_object_get_data(struct l_dbus *dbus, const char *object,
 							interface);
 }
 
-LIB_EXPORT bool l_dbus_object_manager_enable(struct l_dbus *dbus)
+LIB_EXPORT bool l_dbus_object_manager_enable(struct l_dbus *dbus,
+						const char *root)
 {
 	if (unlikely(!dbus))
 		return false;
@@ -1606,7 +1592,7 @@ LIB_EXPORT bool l_dbus_object_manager_enable(struct l_dbus *dbus)
 	if (unlikely(!dbus->tree))
 		return false;
 
-	return _dbus_object_tree_add_interface(dbus->tree, "/",
+	return _dbus_object_tree_add_interface(dbus->tree, root,
 						L_DBUS_INTERFACE_OBJECT_MANAGER,
 						dbus);
 }
@@ -1703,8 +1689,7 @@ LIB_EXPORT unsigned int l_dbus_add_signal_watch(struct l_dbus *dbus,
 	va_start(args, member);
 
 	rule_len = 0;
-	while ((type = va_arg(args, enum l_dbus_match_type)) !=
-			L_DBUS_MATCH_NONE)
+	while (va_arg(args, enum l_dbus_match_type) != L_DBUS_MATCH_NONE)
 		rule_len++;
 
 	va_end(args);
