@@ -1,29 +1,18 @@
 /*
+ * Embedded Linux library
+ * Copyright (C) 2022  Intel Corporation
  *
- *  Embedded Linux library
- *
- *  Copyright (C) 2022  Intel Corporation. All rights reserved.
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <asm/types.h>
+#include <linux/netlink.h>
+#include <linux/rtnetlink.h>
+#include <sys/socket.h>
 #include <net/if.h>
 #include <linux/types.h>
 #include <linux/if_ether.h>
@@ -58,6 +47,7 @@
 #include "net-private.h"
 #include "acd.h"
 #include "timeout.h"
+#include "sysctl.h"
 #include "netconfig.h"
 
 struct l_netconfig {
@@ -89,8 +79,8 @@ struct l_netconfig {
 	unsigned int ifaddr6_dump_cmd_id;
 	struct l_queue *icmp_route_data;
 	struct l_acd *acd;
-	unsigned int orig_disable_ipv6;
-	long orig_optimistic_dad;
+	uint32_t orig_disable_ipv6;
+	uint32_t orig_optimistic_dad;
 	uint8_t mac[ETH_ALEN];
 	struct l_timeout *ra_timeout;
 	bool have_lla;
@@ -558,6 +548,12 @@ static void netconfig_dhcp_event_handler(struct l_dhcp_client *client,
 		if (!l_dhcp_client_start(nc->dhcp_client))
 			netconfig_failed(nc, AF_INET);
 
+		break;
+	case L_DHCP_CLIENT_EVENT_MAX_ATTEMPTS_REACHED:
+		L_WARN_ON(nc->v4_configured);
+
+		netconfig_failed(nc, AF_INET);
+
 		break;
 	}
 }
@@ -1325,59 +1321,25 @@ static int netconfig_proc_write_ipv6_uint_setting(struct l_netconfig *nc,
 							unsigned int value)
 {
 	char ifname[IF_NAMESIZE];
-	_auto_(l_free) char *filename = NULL;
-	_auto_(close) int fd = -1;
-	int r;
-	char valuestr[20];
 
 	if (unlikely(!if_indextoname(nc->ifindex, ifname)))
 		return -errno;
 
-	filename = l_strdup_printf("/proc/sys/net/ipv6/conf/%s/%s",
+	return l_sysctl_set_u32(value, "/proc/sys/net/ipv6/conf/%s/%s",
 					ifname, setting);
-
-	fd = L_TFR(open(filename, O_WRONLY));
-	if (unlikely(fd < 0))
-		return -errno;
-
-	snprintf(valuestr, sizeof(valuestr), "%u", value);
-	r = L_TFR(write(fd, valuestr, strlen(valuestr)));
-	return r > 0 ? 0 : -errno;
 }
 
-static long netconfig_proc_read_ipv6_uint_setting(struct l_netconfig *nc,
-							const char *setting)
+static int netconfig_proc_read_ipv6_uint_setting(struct l_netconfig *nc,
+							const char *setting,
+							uint32_t *out_v)
 {
 	char ifname[IF_NAMESIZE];
-	_auto_(l_free) char *filename = NULL;
-	_auto_(close) int fd = -1;
-	int r;
-	char valuestr[20];
-	long value;
-	char *endp;
 
 	if (unlikely(!if_indextoname(nc->ifindex, ifname)))
 		return -errno;
 
-	filename = l_strdup_printf("/proc/sys/net/ipv6/conf/%s/%s",
+	return l_sysctl_get_u32(out_v, "/proc/sys/net/ipv6/conf/%s/%s",
 					ifname, setting);
-
-	fd = L_TFR(open(filename, O_RDONLY));
-	if (unlikely(fd < 0))
-		return -errno;
-
-	r = L_TFR(read(fd, valuestr, sizeof(valuestr) - 1));
-	if (unlikely(r < 1))
-		return r == 0 ? -EINVAL : -errno;
-
-	valuestr[r - 1] = '\0';
-	errno = 0;
-	value = strtoul(valuestr, &endp, 10);
-
-	if (unlikely(errno || !L_IN_SET(*endp, '\n', '\0')))
-		return -EINVAL;
-
-	return value;
 }
 
 LIB_EXPORT struct l_netconfig *l_netconfig_new(uint32_t ifindex)
@@ -1972,14 +1934,15 @@ static void netconfig_ifaddr_ipv6_dump_cb(int error, uint16_t type,
 static void netconfig_ifaddr_ipv6_dump_done_cb(void *user_data)
 {
 	struct l_netconfig *nc = user_data;
+	int r;
 
 	/*
 	 * Handle the case of no link-local address having been found during
 	 * the dump.  If nc->ifaddr6_dump_cmd_id is 0, we have found one or
-	 * the dump is being cancelled.  Otherwise try disabing the
+	 * the dump is being cancelled.  Otherwise try disabling the
 	 * "disable_ipv6" setting for the interface since it may have been
 	 * enabled.  Also write "addr_gen_mode" which triggers regerating
-	 * the link-local addresss on the interface in the kernel if it
+	 * the link-local address on the interface in the kernel if it
 	 * was previously removed.
 	 */
 	if (!nc->ifaddr6_dump_cmd_id || !nc->started)
@@ -1993,14 +1956,18 @@ static void netconfig_ifaddr_ipv6_dump_done_cb(void *user_data)
 	netconfig_proc_write_ipv6_uint_setting(nc, "addr_gen_mode", 0);
 
 	/* "enable IPv6 operation" */
-	nc->orig_disable_ipv6 =
-		netconfig_proc_read_ipv6_uint_setting(nc, "disable_ipv6");
+	r = netconfig_proc_read_ipv6_uint_setting(nc, "disable_ipv6",
+						&nc->orig_disable_ipv6);
+	if (r < 0) /* TODO: Log error? */
+		nc->orig_disable_ipv6 = 0;
+
 	if (nc->orig_disable_ipv6)
 		netconfig_proc_write_ipv6_uint_setting(nc, "disable_ipv6", 0);
 }
 
 LIB_EXPORT bool l_netconfig_start(struct l_netconfig *netconfig)
 {
+	int r;
 	bool optimistic_dad;
 
 	if (unlikely(!netconfig || netconfig->started))
@@ -2009,6 +1976,9 @@ LIB_EXPORT bool l_netconfig_start(struct l_netconfig *netconfig)
 	if (!netconfig_check_config(netconfig))
 		return false;
 
+	if (!l_net_get_mac_address(netconfig->ifindex, netconfig->mac))
+		return false;
+
 	if (!netconfig->v4_enabled)
 		goto configure_ipv6;
 
@@ -2023,6 +1993,9 @@ LIB_EXPORT bool l_netconfig_start(struct l_netconfig *netconfig)
 		goto configure_ipv6;
 	}
 
+	l_dhcp_client_set_address(netconfig->dhcp_client, ARPHRD_ETHER,
+					netconfig->mac, ETH_ALEN);
+
 	if (!l_dhcp_client_start(netconfig->dhcp_client))
 		return false;
 
@@ -2043,12 +2016,13 @@ configure_ipv6:
 	 */
 	optimistic_dad = netconfig->optimistic_dad_enabled &&
 		!netconfig->v6_static_addr;
-	netconfig->orig_optimistic_dad =
-		netconfig_proc_read_ipv6_uint_setting(netconfig,
-							"optimistic_dad");
 
-	if (netconfig->orig_optimistic_dad >= 0 &&
-			!!netconfig->orig_optimistic_dad != optimistic_dad)
+	r = netconfig_proc_read_ipv6_uint_setting(netconfig, "optimistic_dad",
+				&netconfig->orig_optimistic_dad);
+	if (r < 0) /* TODO: Log error? */
+		netconfig->orig_optimistic_dad = optimistic_dad;
+
+	if (!r && !!netconfig->orig_optimistic_dad != optimistic_dad)
 		netconfig_proc_write_ipv6_uint_setting(netconfig,
 							"optimistic_dad",
 							optimistic_dad ? 1 : 0);
@@ -2102,9 +2076,6 @@ configure_ipv6:
 	l_queue_push_tail(addr_wait_list, netconfig);
 	netconfig->have_lla = false;
 
-	if (!l_net_get_mac_address(netconfig->ifindex, netconfig->mac))
-		goto unregister;
-
 	l_dhcp6_client_set_address(netconfig->dhcp6_client, ARPHRD_ETHER,
 					netconfig->mac, ETH_ALEN);
 	l_icmp6_client_set_address(netconfig->icmp6_client, netconfig->mac);
@@ -2198,8 +2169,7 @@ LIB_EXPORT void l_netconfig_stop(struct l_netconfig *netconfig)
 
 	optimistic_dad = netconfig->optimistic_dad_enabled &&
 		!netconfig->v6_static_addr;
-	if (netconfig->orig_optimistic_dad >= 0 &&
-			!!netconfig->orig_optimistic_dad != optimistic_dad)
+	if (!!netconfig->orig_optimistic_dad != optimistic_dad)
 		netconfig_proc_write_ipv6_uint_setting(netconfig,
 						"optimistic_dad",
 						netconfig->orig_optimistic_dad);
