@@ -1,23 +1,8 @@
 /*
+ * Embedded Linux library
+ * Copyright (C) 2018  Intel Corporation
  *
- *  Embedded Linux library
- *
- *  Copyright (C) 2018  Intel Corporation. All rights reserved.
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifdef HAVE_CONFIG_H
@@ -811,7 +796,8 @@ static struct l_dhcp_client *client_init(const uint8_t *mac)
 				event_handler_lease_obtained, NULL, NULL));
 
 	if (verbose)
-		l_dhcp_client_set_debug(client, do_debug, "[DHCP1] ", NULL);
+		l_dhcp_client_set_debug(client, do_debug, "[DHCP1] ", NULL,
+					L_LOG_DEBUG);
 
 	transport->send = fake_transport_send;
 	transport->l2_send = fake_transport_l2_send;
