@@ -1,23 +1,8 @@
 /*
+ * Embedded Linux library
+ * Copyright (C) 2011-2014  Intel Corporation
  *
- *  Embedded Linux library
- *
- *  Copyright (C) 2011-2014  Intel Corporation. All rights reserved.
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifdef HAVE_CONFIG_H
@@ -941,26 +926,11 @@ static void test_tls_suite_test(const void *data)
 	test_tls_with_ver(&test, 0, 0);
 }
 
-static int read_int_from_file(const char *path)
-{
-	int ret;
-	FILE *file;
-
-	file = fopen(path, "r");
-	if (!file)
-		return 0;
-
-	if (fscanf(file, "%i", &ret) < 1)
-		ret = 0;
-
-	fclose(file);
-	return ret;
-}
-
 int main(int argc, char *argv[])
 {
 	unsigned int i;
-	int maxkeys;
+	uint32_t maxkeys;
+	int r;
 
 	l_test_init(&argc, &argv);
 
@@ -1008,10 +978,9 @@ int main(int argc, char *argv[])
 		goto done;
 	}
 
-	maxkeys = read_int_from_file(getuid() > 0 ?
-					"/proc/sys/kernel/keys/maxkeys" :
-					"/proc/sys/kernel/keys/root_maxkeys");
-	if (maxkeys && maxkeys < 2000)
+	r = l_sysctl_get_u32(&maxkeys, "/proc/sys/kernel/keys/%s",
+				getuid() > 0 ? "maxkeys" : "root_maxkeys");
+	if (!r && maxkeys < 2000)
 		printf("Running sysctl kernel.keys.%s=2000 is recommended\n",
 			getuid() > 0 ? "maxkeys" : "root_maxkeys");
 
